@@ -10,7 +10,7 @@ from contextlib import redirect_stdout
 import io
 import ast
 
-__version__ = '0.1.8'
+__version__ = '0.2.0'
 
 
 def ctrlc(signum, frame):
@@ -80,7 +80,9 @@ def process(data):
                     result_list.append(entry.lstrip("'").rstrip("'"))
 
     except Exception as e:
-        print(e)
+        print(textwrap.dedent(f'''\
+            jello:  Exception - {e}
+            '''), file=sys.stderr)
         sys.exit(1)
 
     if result_list:
@@ -90,7 +92,7 @@ def process(data):
                 list_of_objs.append(json.dumps(obj))
             result = '\n'.join(list_of_objs)
         else:
-            result = '\n'.join(result_list)
+            result = '\n'.join(str(i) for i in result_list)
 
     return result
 
@@ -118,7 +120,7 @@ def pyquery(data, query):
                     jello:  Exception - {e}
                             Cannot parse line {i + 1} (Not JSON or JSON Lines data):
                             {str(jsonline)[:70]}
-                    '''))
+                    '''), file=sys.stderr)
                 sys.exit(1)
 
         json_dict = data_list
@@ -134,13 +136,35 @@ def pyquery(data, query):
     except KeyError as e:
         print(textwrap.dedent(f'''\
             jello:  Key does not exist: {e}
-        '''))
+        '''), file=sys.stderr)
         sys.exit(1)
 
     except IndexError as e:
         print(textwrap.dedent(f'''\
             jello:  {e}
-        '''))
+        '''), file=sys.stderr)
+        sys.exit(1)
+
+    except SyntaxError as e:
+        print(textwrap.dedent(f'''\
+            jello:  {e}
+                    {e.text}
+        '''), file=sys.stderr)
+        sys.exit(1)
+
+    except TypeError as e:
+        print(textwrap.dedent(f'''\
+            jello:  TypeError: {e}
+
+                    If joining a list to output as a bash array, consider:
+                    r = "\\n".join(str(i) for i in the_list)
+        '''), file=sys.stderr)
+        sys.exit(1)
+
+    except Exception as e:
+        print(textwrap.dedent(f'''\
+            jello:  Exception - {e}
+        '''), file=sys.stderr)
         sys.exit(1)
 
     result = process(output)
